@@ -6,11 +6,12 @@ from strictdoc.backend.dsl.writer import SDWriter
 
 
 class PassthroughAction:
-
     def passthrough(self, path_to_doc, output_file):
         if not os.path.isfile(path_to_doc):
             sys.stdout.flush()
-            err = "Could not open doc file '{}': No such file or directory".format(path_to_doc)
+            err = "Could not open doc file '{}': No such file or directory".format(
+                path_to_doc
+            )
             print(err)
             exit(1)
 
@@ -18,5 +19,5 @@ class PassthroughAction:
 
         writer = SDWriter()
         output = writer.write(document)
-        with open(output_file, 'w') as file:
+        with open(output_file, "w") as file:
             file.write(output)
