@@ -11,8 +11,10 @@ from strictdoc.helpers.timing import measure_performance, timing_decorator
 
 class DocumentFinder:
     @staticmethod
-    @timing_decorator('Find')
-    def find_sdoc_content(paths_to_files_or_docs, output_root_html, parallelizer):
+    @timing_decorator("Find")
+    def find_sdoc_content(
+        paths_to_files_or_docs, output_root_html, parallelizer
+    ):
         for paths_to_files_or_doc in paths_to_files_or_docs:
             if not os.path.exists(paths_to_files_or_doc):
                 sys.stdout.flush()
@@ -22,10 +24,12 @@ class DocumentFinder:
                 print(err)
                 exit(1)
 
-        file_tree, asset_dirs = DocumentFinder._build_file_tree(paths_to_files_or_docs)
-        document_tree = DocumentFinder._build_document_tree(file_tree,
-                                                            output_root_html,
-                                                            parallelizer)
+        file_tree, asset_dirs = DocumentFinder._build_file_tree(
+            paths_to_files_or_docs
+        )
+        document_tree = DocumentFinder._build_document_tree(
+            file_tree, output_root_html, parallelizer
+        )
 
         return document_tree, asset_dirs
 
@@ -49,7 +53,9 @@ class DocumentFinder:
         file_tree, doc_file, file_tree_mount_folder = document_triple
         doc_full_path = doc_file.get_full_path()
 
-        with measure_performance('Reading SDOC: {}'.format(os.path.basename(doc_full_path))):
+        with measure_performance(
+            "Reading SDOC: {}".format(os.path.basename(doc_full_path))
+        ):
             reader = SDReader()
             document = reader.read_from_file(doc_full_path)
             assert isinstance(document, Document)
@@ -68,8 +74,7 @@ class DocumentFinder:
 
         file_tree_list = list(DocumentFinder._iterate_file_trees(file_trees))
         found_documents = parallelizer.map(
-            file_tree_list,
-            DocumentFinder.processing
+            file_tree_list, DocumentFinder.processing
         )
 
         for doc_file, document in found_documents:
@@ -82,34 +87,37 @@ class DocumentFinder:
             document = map_docs_by_paths[input_doc_full_path]
             assert isinstance(document, Document)
 
-            doc_relative_path = os.path.relpath(input_doc_full_path, file_tree.root_path)
+            doc_relative_path = os.path.relpath(
+                input_doc_full_path, file_tree.root_path
+            )
             doc_relative_path_folder = os.path.dirname(doc_relative_path)
 
-            output_document_dir_rel_path = '{}/{}'.format(
-                file_tree_mount_folder,
-                doc_relative_path_folder
-            ) if doc_relative_path_folder else file_tree_mount_folder
+            output_document_dir_rel_path = (
+                "{}/{}".format(file_tree_mount_folder, doc_relative_path_folder)
+                if doc_relative_path_folder
+                else file_tree_mount_folder
+            )
 
             document_filename = os.path.basename(input_doc_full_path)
             document_filename_base = os.path.splitext(document_filename)[0]
 
-            output_document_dir_full_path = '{}/{}'.format(
+            output_document_dir_full_path = "{}/{}".format(
                 output_root_html, output_document_dir_rel_path
             )
 
-            document_meta = DocumentMeta(doc_file.level,
-                                         document_filename_base,
-                                         input_doc_full_path,
-                                         output_document_dir_full_path,
-                                         output_document_dir_rel_path)
+            document_meta = DocumentMeta(
+                doc_file.level,
+                document_filename_base,
+                input_doc_full_path,
+                output_document_dir_full_path,
+                output_document_dir_rel_path,
+            )
 
             document.assign_meta(document_meta)
 
             map_docs_by_paths[input_doc_full_path] = document
 
-        return DocumentTree(file_trees,
-                            document_list,
-                            map_docs_by_paths)
+        return DocumentTree(file_trees, document_list, map_docs_by_paths)
 
     @staticmethod
     def _build_file_tree(paths_to_files_or_docs):
@@ -123,40 +131,56 @@ class DocumentFinder:
 
             # Strip away the trailing slash to let the later os.path.relpath
             # calculations work correctly.
-            path_to_doc_root = path_to_doc_root_raw.rstrip('/')
+            path_to_doc_root = path_to_doc_root_raw.rstrip("/")
             path_to_doc_root_base = os.path.dirname(path_to_doc_root)
             root_level = path_to_doc_root.count(os.sep)
 
             tree_map = {path_to_doc_root: FileTree(path_to_doc_root, 0)}
 
-            for current_root_path, dirs, files in os.walk(path_to_doc_root, topdown=False):
-                if os.path.basename(current_root_path) == '_assets':
-                    asset_dirs.append({
-                        'full_path': current_root_path,
-                        'relative_path': os.path.relpath(current_root_path, path_to_doc_root_base)
-                    })
+            for current_root_path, dirs, files in os.walk(
+                path_to_doc_root, topdown=False
+            ):
+                if os.path.basename(current_root_path) == "_assets":
+                    asset_dirs.append(
+                        {
+                            "full_path": current_root_path,
+                            "relative_path": os.path.relpath(
+                                current_root_path, path_to_doc_root_base
+                            ),
+                        }
+                    )
 
-                current_root_path_level = current_root_path.count(os.sep) - root_level
+                current_root_path_level = (
+                    current_root_path.count(os.sep) - root_level
+                )
 
                 if current_root_path not in tree_map:
-                    tree_map[current_root_path] = FileTree(current_root_path, current_root_path_level)
+                    tree_map[current_root_path] = FileTree(
+                        current_root_path, current_root_path_level
+                    )
                 current_tree = tree_map[current_root_path]
 
                 current_tree.sort_subfolder_trees()
 
-                files = [f for f in files if f.endswith('.sdoc')]
-                if len(files) > 0:
-                    files.sort(key=alphanumeric_sort)
-                    current_tree.set(files)
+                files = [f for f in files if f.endswith(".sdoc")]
+                files.sort(key=alphanumeric_sort)
+                current_tree.set(files)
+                if not current_tree.has_sdoc_content and len(files) > 0:
+                    current_tree.has_sdoc_content = True
 
-                    if current_root_path == path_to_doc_root:
-                        continue
+                if current_root_path == path_to_doc_root:
+                    continue
 
-                    current_parent_path = os.path.dirname(current_root_path)
-                    if current_parent_path not in tree_map:
-                        tree_map[current_parent_path] = FileTree(current_parent_path, current_root_path_level - 1)
-                    current_parent_tree = tree_map[current_parent_path]
-                    current_parent_tree.add_subfolder_tree(current_tree)
+                current_parent_path = os.path.dirname(current_root_path)
+                if current_parent_path not in tree_map:
+                    tree_map[current_parent_path] = FileTree(
+                        current_parent_path, current_root_path_level - 1
+                    )
+                current_parent_tree = tree_map[current_parent_path]
+                if len(files) > 0 or current_tree.has_sdoc_content:
+                    current_parent_tree.has_sdoc_content = True
+
+                current_parent_tree.add_subfolder_tree(current_tree)
 
             root_trees.append(tree_map[path_to_doc_root])
         return root_trees, asset_dirs
